@@ -57,10 +57,14 @@ class SubgalSort(make.MakeTask):
     def build(self):
         self.album.log(_("  SORTING pics and subdirs"), 'info')
 
-        if self.album.subgal_sort_by[0] == 'mtime':
+        if self.album.subgal_sort_by[0] == 'exif':
+            subgal_sorter = lambda x, y:\
+                                x.source_dir.compare_latest_exif(y.source_dir)
+        elif self.album.subgal_sort_by[0] == 'mtime':
             subgal_sorter = lambda x, y:\
                                 x.source_dir.compare_mtime(y.source_dir)
-        elif self.album.subgal_sort_by[0] == 'filename':
+        elif self.album.subgal_sort_by[0] == 'dirname'\
+        or self.album.subgal_sort_by[0] == 'filename': # Backward compatibility
             subgal_sorter = lambda x, y:\
                                 x.source_dir.compare_filename(y.source_dir)
         else:
@@ -210,6 +214,17 @@ class WebalbumMediaTask(make.GroupTask):
             for bpage in self.browse_pages.values():
                 if media.thumb: bpage.add_dependency(media.thumb)
 
+    def get_original_or_symlink(self):
+        if not self.album.orig_symlink:
+            return genfile.MediaOriginal(self.webgal, self.media)
+        else:
+            return genfile.SymlinkMediaOriginal(self.webgal, self.media)
+
+    def get_original(self):
+        if not self.original:
+            self.original = self.get_original_or_symlink()
+        return self.original
+
 
 class WebalbumImageTask(WebalbumMediaTask):
     """
@@ -223,17 +238,6 @@ class WebalbumImageTask(WebalbumMediaTask):
                                              genmedia.THUMB_SIZE_NAME)
         self.add_dependency(self.thumb)
 
-    def get_original_or_symlink(self):
-        if not self.album.orig_symlink:
-            return genfile.ImageOriginal(self.webgal, self.media)
-        else:
-            return genfile.SymlinkImageOriginal(self.webgal, self.media)
-
-    def get_original(self):
-        if not self.original:
-            self.original = self.get_original_or_symlink()
-        return self.original
-
     def get_resized(self, size_name):
         if self.album.browse_size_strings[size_name] == '0x0':
             return self.get_original_or_symlink()
@@ -258,9 +262,6 @@ class WebalbumVideoTask(WebalbumMediaTask):
 
         self.add_dependency(self.webvideo)
 
-    def get_original(self):
-        return self.get_resized("0x0")
-
     def get_browse_page(self, size_name):
         return genpage.WebalbumVideoPage(self.webgal, size_name, self)
 
