@@ -80,15 +80,20 @@ class ImageOtherSize(genfile.WebalbumFile):
     )
 
     def __build_other_size(self, im):
-        new_size = self.newsizer.dest_size(im.size)
-
-        im.draft(None, new_size)
-        im = im.resize(new_size, Image.ANTIALIAS)
-
         # Use EXIF data to rotate target image if available and required
         rotation = self.source_image.info().get_required_rotation()
+
+        if rotation != 0 and rotation % 90 == 0:
+            img_size = (im.size[1], im.size[0], ) # swap coords
+        else:
+            img_size = im.size
+
+        new_size = self.newsizer.dest_size(img_size)
+
+        im.draft(None, new_size)
         if rotation != 0:
             im = im.rotate(rotation)
+        im = im.resize(new_size, Image.ANTIALIAS)
 
         calibrated = False
         while not calibrated:
@@ -111,6 +116,10 @@ class ImageOtherSize(genfile.WebalbumFile):
         imgtags.copy(dest_imgtags)
         dest_imgtags['Exif.Photo.PixelXDimension'] = new_size[0]
         dest_imgtags['Exif.Photo.PixelYDimension'] = new_size[1]
+        if rotation != 0:
+            # Smaller image has been rotated in order to be displayed correctly
+            # in a web browser. Fix orientation tag accordingly.
+            dest_imgtags['Exif.Image.Orientation'] = 1
         # Those are removed from published pics due to pivacy concerns
         for tag in self.PRIVATE_IMAGE_TAGS:
             try:
@@ -145,6 +154,13 @@ class WebalbumPicture(make.FileMakeObject):
             self.add_dependency(thumb)
 
         if webgal_dir.source_dir.album_picture:
+            albumpic_path = os.path.join(webgal_dir.source_dir.path,
+                                         webgal_dir.source_dir.album_picture)
+            if not os.path.isfile(albumpic_path):
+                self.album.log(_("Supplied album picture %s does not exist.")\
+                               % webgal_dir.source_dir.album_picture,
+                               'error')
+
             md_dirpic_thumb = self.album._add_size_qualifier(\
                                            webgal_dir.source_dir.album_picture,
                                            THUMB_SIZE_NAME)
@@ -184,10 +200,11 @@ class WebVideo(genfile.WebalbumFile):
         try:
             transcoder.convert(self.source_video.path, self.path)
         except mediautils.TranscodeError, e:
-            self.dir.album.log(_("  %s is BROKEN, skipped")\
+            self.dir.album.log(_("  transcoding %s failed, skipped")\
                                % self.source_video.filename,
                                'error')
-            self.dir.album.log(e, 'info')
+            self.dir.album.log(str(e), 'info')
+            os.unlink(self.path)
 
 
 # vim: ts=4 sw=4 expandtab
