@@ -17,6 +17,7 @@
 
 import os, locale
 import codecs
+import datetime
 import Image
 
 from lazygal import pyexiv2api as pyexiv2
@@ -82,31 +83,34 @@ class ImageInfoTags(object):
         as those were filled by camera, Image DateTime can be update by
         software when editing photos later.
         '''
-        date = None
-        try:
-            date = self.get_tag_value('Exif.Photo.DateTimeDigitized')
-        except (IndexError, ValueError, KeyError):
+        for date_tag in ('Exif.Photo.DateTimeDigitized',
+                         'Exif.Photo.DateTimeOriginal',
+                         'Exif.Image.DateTime',
+                        ):
             try:
-                date = self.get_tag_value('Exif.Photo.DateTimeOriginal')
+                date = self.get_tag_value(date_tag)
+                if type(date) is not datetime.datetime:
+                    # Sometimes, pyexiv2 sends a string. It seems to happen on
+                    # malformed tags.
+                    raise ValueError
             except (IndexError, ValueError, KeyError):
-                try:
-                    date = self.get_tag_value('Exif.Image.DateTime')
-                except (IndexError, ValueError, KeyError):
-                    # No date available in EXIF
-                    pass
-        # Some pics give a zeroed date which is not recognized by pyexiv2 as a
-        # date.
-        if date == '0000:00:00 00:00:00': date = None
-        return date
+                pass
+            else:
+                return date
+
+        # No date could be found in the picture metadata
+        return None
 
     def get_required_rotation(self):
         try:
             orientation_code = self.get_tag_value('Exif.Image.Orientation')
             if orientation_code == 8:
                 return 90
+            elif orientation_code == 3:
+                return 180
             elif orientation_code == 6:
                 return 270
-            else:
+            else: # Should be orientation_code == 1 but catch all
                 return 0
         except KeyError:
             return 0
@@ -153,9 +157,9 @@ class ImageInfoTags(object):
             return self.get_tag_value('Exif.Pentax.LensType')
         except (IndexError, ValueError, KeyError):
             try:
-                ret = self.get_tag_value('Exif.Nikon3.Lens')
+                ret = self._metadata['Exif.Nikon3.Lens'].human_value.strip()
                 try:
-                    ret2 = self.get_tag_value('Exif.Nikon3.LensType')
+                    ret2 = self._metadata['Exif.Nikon3.LensType'].human_value.strip()
                 except (IndexError, ValueError, KeyError):
                     return ret
                 else:
@@ -399,7 +403,7 @@ class DirectoryMetadata(make.GroupTask):
         if 'album_picture' not in metadata.keys():
             fmd = FileMetadata(os.path.join(subdir, 'album-picture')).contents(splitter='\n')
             if fmd is not None:
-                metadata['album_picture'] = fmd[0]
+                metadata['album_picture'] = os.path.join(subdir, fmd[0])
 
         return metadata
 
